==> huaweicloudsdkcodeartsdeploy-3.1.109-py2.py3-none-any.whl: huaweicloudsdkcodeartsdeploy/v2/model/move_app_to_group_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class MoveAppToGroupResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'result': 'list[MoveAppToGroupResult]',
        'status': 'str'
    }

    attribute_map = {
        'result': 'result',
        'status': 'status'
    }

    def __init__(self, result=None, status=None):
        """MoveAppToGroupResponse

        The model defined in huaweicloud sdk

        :param result: 移动应用至指定分组结果，仅返回移动失败的列表
        :type result: list[:class:`huaweicloudsdkcodeartsdeploy.v2.MoveAppToGroupResult`]
        :param status: 请求成功失败状态
        :type status: str
        """
        
        super(MoveAppToGroupResponse, self).__init__()

        self._result = None
        self._status = None
        self.discriminator = None

        if result is not None:
            self.result = result
        if status is not None:
            self.status = status

    @property
    def result(self):
        """Gets the result of this MoveAppToGroupResponse.

        移动应用至指定分组结果，仅返回移动失败的列表

        :return: The result of this MoveAppToGroupResponse.
        :rtype: list[:class:`huaweicloudsdkcodeartsdeploy.v2.MoveAppToGroupResult`]
        """
        return self._result

    @result.setter
    def result(self, result):
        """Sets the result of this MoveAppToGroupResponse.

        移动应用至指定分组结果，仅返回移动失败的列表

        :param result: The result of this MoveAppToGroupResponse.
        :type result: list[:class:`huaweicloudsdkcodeartsdeploy.v2.MoveAppToGroupResult`]
        """
        self._result = result

    @property
    def status(self):
        """Gets the status of this MoveAppToGroupResponse.

        请求成功失败状态

        :return: The status of this MoveAppToGroupResponse.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this MoveAppToGroupResponse.

        请求成功失败状态

        :param status: The status of this MoveAppToGroupResponse.
        :type status: str
        """
        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MoveAppToGroupResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcodeartsdeploy-3.1.150-py2.py3-none-any.whl: huaweicloudsdkcodeartsdeploy/v2/model/move_app_to_group_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class MoveAppToGroupResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'result': 'list[MoveAppToGroupResult]',
        'status': 'str'
    }

    attribute_map = {
        'result': 'result',
        'status': 'status'
    }

    def __init__(self, result=None, status=None):
        r"""MoveAppToGroupResponse

        The model defined in huaweicloud sdk

        :param result: 移动应用至指定分组结果，仅返回移动失败的列表
        :type result: list[:class:`huaweicloudsdkcodeartsdeploy.v2.MoveAppToGroupResult`]
        :param status: 请求成功失败状态
        :type status: str
        """
        
        super(MoveAppToGroupResponse, self).__init__()

        self._result = None
        self._status = None
        self.discriminator = None

        if result is not None:
            self.result = result
        if status is not None:
            self.status = status

    @property
    def result(self):
        r"""Gets the result of this MoveAppToGroupResponse.

        移动应用至指定分组结果，仅返回移动失败的列表

        :return: The result of this MoveAppToGroupResponse.
        :rtype: list[:class:`huaweicloudsdkcodeartsdeploy.v2.MoveAppToGroupResult`]
        """
        return self._result

    @result.setter
    def result(self, result):
        r"""Sets the result of this MoveAppToGroupResponse.

        移动应用至指定分组结果，仅返回移动失败的列表

        :param result: The result of this MoveAppToGroupResponse.
        :type result: list[:class:`huaweicloudsdkcodeartsdeploy.v2.MoveAppToGroupResult`]
        """
        self._result = result

    @property
    def status(self):
        r"""Gets the status of this MoveAppToGroupResponse.

        请求成功失败状态

        :return: The status of this MoveAppToGroupResponse.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        r"""Sets the status of this MoveAppToGroupResponse.

        请求成功失败状态

        :param status: The status of this MoveAppToGroupResponse.
        :type status: str
        """
        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MoveAppToGroupResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
